clear all
close all
clc

%% Data
%OBS      GPA      TUCE     PSI      GRADE 
data = [
  1      2.66      20      0        0  
  2      2.89      22      0        0  
  3      3.28      24      0        0  
  4      2.92      12      0        0  
  5      4.00      21      0        1  
  6      2.86      17      0        0  
  7      2.76      17      0        0  
  8      2.87      21      0        0  
  9      3.03      25      0        0  
 10      3.92      29      0        1  
 11      2.63      20      0        0  
 12      3.32      23      0        0  
 13      3.57      23      0        0  
 14      3.26      25      0        1  
 15      3.53      26      0        0  
 16      2.74      19      0        0  
 17      2.75      25      0        0  
 18      2.83      19      0        0  
 19      3.12      23      1        0  
 20      3.16      25      1        1  
 21      2.06      22      1        0  
 22      3.62      28      1        1  
 23      2.89      14      1        0  
 24      3.51      26      1        0  
 25      3.54      24      1        1  
 26      2.83      27      1        1  
 27      3.39      17      1        1  
 28      2.67      24      1        0  
 29      3.65      21      1        1  
 30      4.00      23      1        1  
 31      3.10      21      1        0  
 32      2.39      19      1        1
 ];

%Greene (2002) - Table F21.1: Program Effectiveness, 32 Cross Section Observations
%Source: Spector and Mazzeo (1980).
%   * Obs = observation,
%   * TUCE = Test score on economics test,
%   * PSI = participation in program,
%   * GRADE = Grade increase (1) or decrease (0) indicator 
%   * GPA = grade point average

%The data listed in Appendix Table F21.1 were taken from a study by Spector and Mazzeo
%(1980), which examined whether a new method of teaching economics, the Personalized
%System of Instruction (PSI), significantly influenced performance in later economics courses.
%The dependent variable used in our application is GRADE, which indicates the whether
%a students grade in an intermediate macroeconomics course was higher than that in the
%principles course. The other variables are GPA, their grade point average; TUCE, the score
%on a pretest that indicates entering knowledge of the material; and PSI, the binary variable
%indicator of whether the student was exposed to the new teaching method. (Spector and
%Mazzeos specific equation was somewhat different from the one estimated here.)

%model:
%GRADE = b1 + b2*GPA + b3*TUCE + b4*PSI + eps

GPA   = data(:,2);
TUCE  = data(:,3);
PSI   = data(:,4);
GRADE = data(:,5);
